@@ -249,11 +249,19 @@ export async function createSuggestionModal(
 
         const savedSelection = saveEditorSelection(editor);
         let modalHtml;
+        // Can be null on create ticket page
+        const ticketId = getTicketIdFromUrl(window.location.href);
+        let queueId;
+        if ( !ticketId ) {
+            queueId = document.querySelector('#ai-queue')?.getAttribute('data-id');
+        }
+
         try {
             modalHtml = await loadModalContent(RT.Config.WebHomePath + '/Helpers/AISuggestion/ShowModal', {
                 rawText: editorContent,
                 callType,
-                TicketId: getTicketIdFromUrl(window.location.href)
+                ...(ticketId && { TicketId: ticketId }),
+                ...(queueId && { QueueId: queueId })
             });
         } catch (error) {
             console.error('Failed to load modal content:', error);
